@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1100';
+our $VERSION = '0.1101';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -284,7 +284,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1100
+version 0.1101
 
 =head1 SYNOPSIS
 
@@ -362,7 +362,8 @@ The diatonic mode names supported are:
 
 Note on which the C<major> scale is based.  Default: C<'C'>
 
-This must be an uppercase letter from A-G and followed by a C<#>.
+This must be an uppercase letter from A-G and followed by a C<#> or
+C<b>.
 
 This attribute is required when the B<scale_note> is either a
 double-sharp or double-flat and the B<scale_name> is neither C<major>
@@ -375,8 +376,6 @@ designations?
 
 Default: C<1>
 
-* Must be a Boolean value.
-
 If this is set to C<0>, single notes can be used to return the
 major/minor Roman numeral for the given diatonic mode B<scale_name>.
 
@@ -389,8 +388,10 @@ Show the progress of the B<parse> method.  Default C<0>
 =head2 new
 
   $mtr = Music::ToRoman->new(
-    scale_note => $note,
-    scale_name => $name,
+    scale_note  => $note,
+    scale_name  => $name,
+    major_tonic => $tonic,
+    verbose     => $verbose,
   );
 
 Create a new C<Music::ToRoman> object.
@@ -418,6 +419,10 @@ Roman numeral representation.
 A diminished chord may be given as either C<o> or C<dim>, and both are
 rendered as C<o>.
 
+If the B<scale_note> to parse is a double accidental and the
+B<scale_name> is not C<major> (or C<ionian>), the B<major_tonic> must
+be supplied.
+
 =head1 SEE ALSO
 
 L<List::MoreUtils>
